#!/bin/sh

SBOX_DIR=/scratchbox

PKG_INFO_DIR="deb_list"

SB_DEVKIT_ROOT="$SBOX_DIR/devkits"
SB_COMPILER_ROOT="$SBOX_DIR/compilers"

SB_INFO_DIRS="$SBOX_DIR/tools/$PKG_INFO_DIR"

function parse_sb_config
{
	if [ -d /host_usr/$PKG_INFO_DIR ]; then
		SB_INFO_DIRS="/host_usr/$PKG_INFO_DIR $SB_INFO_DIRS"
	fi

	local devkits="`$SBOX_DIR/tools/bin/sb-conf show --devkits`"
	if [ x"$devkits" != xnone ]; then
		for devkit in $devkits; do
			SB_INFO_DIRS="$SB_INFO_DIRS $SB_DEVKIT_ROOT/$devkit/$PKG_INFO_DIR"
		done
	fi

	SB_INFO_DIRS="$SB_INFO_DIRS $SB_COMPILER_ROOT/`$SBOX_DIR/tools/bin/sb-conf show --compiler`/$PKG_INFO_DIR"
}

function list_all
{
	(for file in `find $SB_INFO_DIRS -type f`; do
		local ver=`grep '^Version: ' $file | cut -d' ' -f2`
		for pkg in `grep '^Binary: ' $file | cut -d' ' -f2-`; do
			echo "$pkg=$ver"
		done
	 done
	) | sort -u

	exit
}

function list_sources
{
	(for file in `find $SB_INFO_DIRS -type f`; do
		local src=`grep '^Source: ' $file | cut -d' ' -f2`
		local ver=`grep '^Version: ' $file | cut -d' ' -f2`
		echo "$src=$ver"
	 done
	) | sort -u

	exit
}

function pkg_info
{
	local PACKAGE=$1
	local found=false

	for file in `find $SB_INFO_DIRS -type f` ; do
		if (grep '^Binary: ' $file; echo -n ' ') | grep -q " $PACKAGE "; then
			cat $file
			found=true
			break
		fi
	done

	if ! $found ; then
		exit_error "Package not found: $PACKAGE"
	fi

	exit 0
}

function source_info
{
	local PACKAGE=$1
	local found=false

	for file in `find $SB_INFO_DIRS -type f` ; do
		if grep -q "^Source: $PACKAGE$" $file; then
			cat $file
			found=true
			break
		fi
	done

	if ! $found ; then
		exit_error "Package not found: $PACKAGE"
	fi
	
	exit 0
}

function exit_error
{
	echo >&2 "$0: $@"
	exit 1
}

function usage
{
	local error=$1

	cat <<EOF
Lists Debian packages provided by Scratchbox

Usage: $0 [-h] [-l] [-s] [-i pkg] [-f pkg]

	-h         show this help
	-l         list all packages in this configuration
	-s         list all sources used for this configuration
	-i <pkg>   show info about package
	-f <pkg>   show info about source package

EOF
	exit $error
}

parse_sb_config

while getopts lhsi:f: opt
  do
  case $opt in
	  h) usage 0;;
	  l) list_all;;
	  s) list_sources;;
	  i) pkg_info $OPTARG;;
	  f) source_info $OPTARG;;
	  ?) usage 1;;
  esac; 
done

usage 1
